;A little puzzle game...

#include "ti86asm.inc"

MAXLEVEL = 100

.org _asm_exec_ram

    nop
    jp Start
    .dw 0
    .dw Title

Title:
.db "Picross v1.1",0

Level       = _textShadow
Timer1      = _textShadow+1
TimerSec    = _textShadow+2
Score       = _textShadow+5
TimerActive = _textShadow+7
SprY        = _textShadow+8
SprX        = _textShadow+9
Live        = _textShadow+10
GameOverFlg = _textShadow+11
InfoTxtH    = _plotSScreen+520   ;12
InfoTxtV    = _plotSScreen+550   ;42
MissCnt     = _textShadow+70
Size        = _textShadow+72    ;_cmdShadow


LevelMatrix = _plotSScreen  ;16x16 matrix containing "uncompressed" level
UserMatrix  = _plotSScreen+260

Start:
    sub A
    ld  (Level), A
    call _clrLCD
    call _runindicoff
    call _flushallmenus
    res appTextSave,(iy+appflags)
    ld  A, (BestLevel)
    and A
    jr  z, NoLevelSelect
    ld  HL, $0103
    ld  (_curRow), HL
    ld  HL, LevelSelectStr
    call _puts
    ld  B, 0
    jr  RedrawLevelSel
LevelSelect:
    halt
    push bc
    call _getky
    pop bc
    and A
    jr  z, LevelSelect
    cp  K_UP
    jr  z, NextLevel
    cp  K_DOWN
    jr  z, PreviousLevel
    cp  K_ENTER
    jr  z, LevelSelectDone
    cp  K_CLEAR
    jr      nz, LevelSelect
ClearBestLevel:
    sub A
    ld  (BestLevel), A
    jr  NoLevelSelect
NextLevel:
    ld  A, (BestLevel)
    cp  B
    jr  z, LevelSelect
    inc B
    jr  RedrawLevelSel
PreviousLevel:
    inc B
    dec B
    jr  z, LevelSelect
    dec B
RedrawLevelSel:
    ld  HL, $0F03
    ld  (_curRow), HL
    ld  L, B
    inc L
    ld  H, 0
    xor a
    call _dispAHL
    jr  LevelSelect
LevelSelectDone:
    ld  A, B
    ld  (Level), A
NoLevelSelect:
    ;set textInverse, (IY+textflags)
    call InstallInt
    ld  A, 3
    ld  (Live), A
    ld  HL, 0
    ld  (Score), HL
GameStart:
    call _clrLCD
    call    DrawStuff
    call    PrepareLevel
    ld  BC, 0
    call    DrawPointer
    sub A
    ld  (GameOverFlg), A
    call    GenHorzInfo
    call    GenVertInfo
GameLoop:
    ld  A, (GameOverFlg)
    and A
    jp  nz, LoseLife
    ld  A, (MissCnt)
    and A
    jr  z, GameLoop_
    ld  E, A
    ld  A, (TimerSec)
    cp  E
    call    c, ClearMiss
GameLoop_:
    halt
    push bc
    call _getky
    pop bc
    and A
    jr  z, GameLoop
    push    AF
    call    DrawPointer
    call    ClearHorzInfo    ;Ta bort siffror
    call    ClearVertInfo    ;Ta bort siffror
    ld  A, (Size)
    and A
    ld  D, 7
    jr  z, MaxSize
    ld  D, 15
MaxSize:
    pop AF
    cp  K_UP
    jr  nz, CheckDown
    ld  A, C
    and A
    jr  z, RedrawPointer
    dec C
    jr      RedrawPointer
CheckDown:
    cp  K_DOWN
    jr  nz, CheckLeft
    ld  A, C
    cp  D
    jr  nc, RedrawPointer
    inc C
    jr  RedrawPointer
CheckLeft:
    cp  K_LEFT
    jr  nz, CheckRight
    ld  A, B
    and A
    jr  z, RedrawPointer
    dec B
    jr  RedrawPointer
CheckRight:
    cp  K_RIGHT
    jr  nz, CheckSecond
    ld  A, B
    cp  D
    jr  nc, RedrawPointer
    inc B
    jr  RedrawPointer
CheckSecond:
    cp  K_SECOND
    jr  nz, CheckPause
    call    GenMapOffset
    ld  HL, UserMatrix
    add HL, DE
    push    HL
    ld  A, (HL)
    and A
    jr  nz, CheckSecond_
    ld  HL, LevelMatrix
    add HL, DE
    ld  A, (HL)
    and A
    jr  nz, CheckSecond_
    pop HL
    ld  A, (TimerSec)
    sub 5
    ld  (TimerSec), A
    push    AF
    call    DispMiss
    pop AF
    jr  c, LoseLife
    jr  z, LoseLife
    jr      RedrawPointer
CheckSecond_:
    pop HL
    ld  A, (HL)
    xor 1
    ld  (HL), A
    call    FillTile
    call    Compare
    jr  RedrawPointer
CheckPause:
    cp  K_MORE
    jr  nz, CheckExit
    sub A
    ld  (TimerActive), A
    call OTH_PAUSE
    ld  A, 1
    ld  (TimerActive), A
    jr  RedrawPointer
CheckExit:
    cp  K_EXIT
    jr  z, Exit
RedrawPointer:
    call    GenHorzInfo
    call    GenVertInfo
    call    DrawPointer
    jp  GameLoop

Exit:
    ld hl,_asapvar
    rst 20h
    rst 10h
    ld a,b
    ld hl,BestScore-_asm_exec_ram+4
    add hl,de
    adc a,0
    call _set_abs_dest_addr
    xor a
    ld hl,BestScore
    call _set_abs_src_addr
    ld hl,3
    call _set_mm_num_bytes
    call _mm_ldir
    set appTextSave,(iy+appflags)
    call _clrScrn
    res 2,(iy+$23)
    res 3, (IY+5)
    set graphdraw,(iy+graphflags)
    jp _homeup

LoseLife:
    ei
    sub A
    ld  (TimerActive), A
    ld  HL, $0503
    ld  (_curRow), HL
    ld  HL, TimeUpStr
    set textInverse,(iy+textflags)
    call _puts
    res textInverse,(iy+textflags)
    call    OTH_PAUSE
    ld  A, (Live)
    dec A
    ld  (Live), A
    jp  nz, GameStart
GameIsOver:
    sub A
    ld  (TimerActive), A
    ld  HL, 7
    ld  (_curRow), HL
    ld  HL, GameOverStr
    set textInverse,(iy+textflags)
    call _puts
    ld  HL,  $FC00+(56*16)
    ld  (HL), 255
    ld  BC, 8*16-1
    call    OTH_FILL
    ld  B, 63-15
ScrollDown:
    push    BC
    ld  HL,  $FC00+16
    ld  DE,  $FC00
    ld  BC, 1024-16
    ldir
    pop BC
    halt
    halt
    halt
    halt
    halt
    halt
    halt
    halt
    djnz    ScrollDown
    call    OTH_PAUSE
    jp  Exit
GameDone:
    res 3, (IY+5)
    call _clrLCD
    ld  HL, 0
    ld  (_curRow), HL
    ld  HL, DoneStr
    call _puts
    call    OTH_PAUSE
    jr  GameIsOver

DispMiss:
    call    ClearMiss
    ld  HL, $0302
    ld  (_curRow), HL
    ld  HL, MissStr
    set textInverse,(iy+textflags)
    call _puts
    res textInverse,(iy+textflags)
    ld  A, (TimerSec)
    sub 2
    ld  (MissCnt), A
    ret

ClearMiss:
    push    BC
    ld  HL,  $FC00+(12*16)
    ld  B, 19
ClearMiss_Loop:
    push    BC
    ld  BC, 7
    call    OTH_CLEAR
    pop BC
    ld  DE, 9
    add HL, DE
    djnz    ClearMiss_Loop
    sub A
    ld  (MissCnt), A
    pop BC
    ret

DrawStuff:
    ld  DE, TitlePic
    ld      C, 12
    ld  HL,  $FC00
DrawTitleLoop:
    ld  B, 8
DrawTitleLoop_:
    ld  A, (DE)
    inc DE
    ld  (HL), A
    inc HL
    djnz    DrawTitleLoop_
    push    DE
    ld  DE, 8
    add HL, DE
    pop DE
    dec C
    jr  nz, DrawTitleLoop
    ld  C, 0
AreaLoop:
    push    BC
    ld  D, 127-98
    ld  B, 99
    call    HLine
    pop BC
    inc C
    ld  A, C
    cp  7
    jr  c, AreaLoop
    ld  HL, (12*256)+9
    ld  (_penCol), HL
    ld  HL, ByStr
    call    _vputs
    ld  DE, (18*256)+26
    ld  (_penCol), DE
    call    _vputs
    ld  DE, (24*256)+1
    ld  (_penCol), DE
    call    _vputs
    ld  DE, (7*256)+100
    ld  (_penCol), DE
    call    _vputs
    ld  DE, (19*256)+100
    ld  (_penCol), DE
    call    _vputs
    ld  DE, (31*256)+100
    ld  (_penCol), DE
    call    _vputs
    ld  DE, (43*256)+100
    ld  (_penCol), DE
    call    _vputs
    ld  DE, (56*256)+100
    ld  (_penCol), DE
    call    _vputs
    ld  DE, (0*256)+104
    ld  (_penCol), DE
    set textInverse,(iy+textflags)
    call    _vputs
    res textInverse,(iy+textflags)
    ld  BC, 31
    ld  D, 98
    call    HLine
    ld  BC, 65*256
    ld  D, 64
    call    VLine
    ld  BC, 98*256
    ld  D, 64
    call    VLine
    ret

;horizontal line: B = start x, D = len, C = y
HLine:
    ;ld A, 63
    ;sub    C
    ;ld C, A
    call    Find_Pixel      ;B=x C=y
    ld  B, D
    ld  C, A
HLineLoop:
    ld  A, (HL)
    or  C
    ld  (HL), A
    rrc C
    jr  nc, HLineLoop_
    inc HL
HLineLoop_:
    djnz    HLineLoop
    ret

;vertical line: B = x, C = start y, D = len
VLine:
    ;ld A, 63
    ;sub    C
    ;ld C, A
    call    Find_Pixel
    ld  B, D
    ld  C, A
    ld  DE, 16
VLineLoop:
    ld  A, (HL)
    or  C
    ld  (HL), A
    add HL, DE
    djnz    VLineLoop
    ret

;xor tile (B=x,C=y)
FillTile:
    push    BC
    call    CalcPos
    ld  A, (Size)
    ld  HL, Tile44
    and A
    jr  z, FillTile_
    ld  HL, Tile22
FillTile_:
    call    PutSprite
    pop BC
    ret

;xor tile (B=x,C=y)
DrawPointer:
    push    BC
    call    CalcPos
    ld  HL, Pointer
    call    PutSprite
    pop BC
    ret

CalcPos:
    sla B
    sla C
    ld  A, (Size)
    and A
    jr  nz, CalcPos_
    sla B
    sla C
CalcPos_:
    ld  A, B
    add A, 66
    ld      B, A
    ld  A, C
    add A, 32
    ld  C, A
    ret

PrepareLevel:
    ld  A, (Level)
    ld  B, A
    ld  HL, Levels
    and A
    jr  z, GotLevel
    ld  DE, 8+2
GetLevel:
    add HL, DE
    ld  A, (HL)
    and A
    ld  E, 8+2
    jr  z, GetLevel_
    ld  E, 32+2
GetLevel_:
    djnz    GetLevel
GotLevel:
    sub A
    ld  (TimerActive), A
    ld  A, (HL)
    ld  (Size), A
    inc HL
    ld  A, (HL)
    add A, 30
    ld  (TimerSec), A
    ld  A, 250
    ld  (Timer1), A
    inc HL
;"uncompress" level
    ld  B, 128
    ld  A, (Size)
    and A
    ld  C, 8
    jr  z, UncompressLevel_
    ld  C, 32
UncompressLevel_:
    ld  DE, LevelMatrix
UncompressLevel:
    ld  A, (HL)
    and B
    ld  A, 0
    jr  z, SetMatrix
    inc A
SetMatrix:
    ld  (DE), A
    inc DE
    rrc B
    jr  nc, UncompressLevel
    inc HL
    dec C
    jr  nz, UncompressLevel

    ld  HL, (Score)
    ld  DE, (25*256)+100
    ld  (_penCol), DE
    call    DispHL
    ld  HL, (BestScore)
    ld  DE, (37*256)+100
    ld  (_penCol), DE
    call    DispHL
    ld  DE, (49*256)+100
    ld  (_penCol), DE
    ld  A, (Level)
    inc A
    ld  L, A
    ld  H, 0
    call    DispHL
    ld  DE, (56*256)+115
    ld  (_penCol), DE
    ld  A, (Live)
    ld  L, A
    ld  H, 0
    call    DispHL

    ld  HL, UserMatrix
    ld  BC, 511
    call    OTH_CLEAR

    ld  A, 1
    ld  (TimerActive), A
    ret

GenMapOffset:
    push    BC
    sla C
    sla C
    sla C
    ld  A, (Size)
    and A
    jr  z, GenMapOffset_
    sla C
GenMapOffset_:
    ld  A, C
    add A, B
    ld  E, A
    ld  D, 0
    pop BC
    ret

Compare:
    push    BC
    ld  A, (Size)
    ld  B, 64
    and A
    jr  z, Compare_
    ld  B, 0
Compare_:
    ld  HL, UserMatrix
    ld  DE, LevelMatrix
CompareLoop:
    ld  A, (DE)
    cp  (HL)
    jr  nz, NotSame
    inc HL
    inc DE
    djnz    CompareLoop
Same:
    sub A
    ld  (TimerActive), A
;count down timer, up score, set best score, next level
    res 3, (IY+5)
ScoreLoop:
    ld  B, 10
HaltLoop:
    halt
    djnz    HaltLoop
    ld  A, (TimerSec)
    dec A
    ld  (TimerSec), A
    jr  z, ScoreLoopDone
    ld  L, A
    ld  H, 0
    call    DispTime
    ld  HL, (Score)
    inc HL
    ld  (Score), HL
    ld  DE, (25*256)+100
    ld  (_penCol), DE
    call    DispHL
    ld  DE, (BestScore)
    ld  HL, (Score)
    call    _cphlde
    jr  c, ScoreLoop
    ld  (BestScore), HL
    ld  DE, (37*256)+100
    ld  (_penCol), DE
    call    DispHL
    jr  ScoreLoop
ScoreLoopDone:
    set 3, (IY+5)
    ld  HL, $0503
    ld  (_curRow), HL
    ld  HL, StageDone
    call _puts
    res 3, (IY+5)
    call    OTH_PAUSE
    ld  A, (BestLevel)
    ld  B, A
    ld  A, (Level)
    inc A
    ld  (Level), A
    cp  B
    jr  c, NoBestLevel
    ld  (BestLevel), A
NoBestLevel:
    cp  MAXLEVEL
    pop BC
    pop HL
    jp  c, GameStart
    jp  GameDone
NotSame:
    pop BC
    ret

DispTime:
    push    HL
    ld  DE, (13*16)+13
    ld  HL,  $FC00
    add HL, DE
    ld  B, 6
    ld  DE, 15
DispTimeLoop:
    ld  (HL), 0
    inc HL
    ld  (HL), 0
    add HL, DE
    djnz    DispTimeLoop
    pop HL
    ld  DE, (13*256)+100
    ld  (_penCol), DE
    call    DispHL
    ret

;blit 4x4 sprite (HL) to B,C
PutSprite:
    push    BC
    push    DE
convdone:
    ;ld     A, 63
    ;sub    C
    ;ld     C, A
    push    HL
    push    HL
    call    Find_Pixel
    ex  DE, HL
    pop     HL
    ld  B, (HL)
    inc HL
    ld  C, (HL)
    inc HL
    push    HL
    pop IX
    ex  DE, HL
PS_NewRow:
    push    BC
    ld  D, (IX)
    inc     IX
    push    AF
    push    HL
PS_NewCol:
    rl  D
    ld  E, A
    jr  nc, PS_NextPixel
    xor     (HL)
    ld  (HL), A
PS_NextPixel:
    ld  A, E
    rrca
    jr  nc, PS_SameByte
    inc     HL
PS_SameByte:
    djnz    PS_NewCol
    pop     HL
    pop     AF
    ld  DE, 16
    add     HL, DE
    pop     BC
    dec     C
    jr  nz, PS_NewRow
    pop     HL
    pop     DE
    pop     BC
    ret


;--------------- Interrupt routine ----------------
int_copy:
int_start:
TimerInt:
    ld  A, (TimerActive)
    and A
    ret z
    ld  HL, Timer1
    dec (HL)
    ret nz
    ld  (HL), 250
    inc HL
    dec (HL)
    jr  nz, TimerIntDisp
TimerIntGameOver:
    ld  A, 1
    ld  (GameOverFlg), A
TimerIntDisp:
    ld  A, (HL)
    cp  250
    jr  nc, TimerIntGameOver
    ld  L, A
    ld  H, 0
    ld  DE, (_penCol)
    push    DE
    in a,(5)
    ld (RomPage),a
    ld a,%00001101
    out (5),a
    call    DispTime
    ld a,(RomPage)
    out (5),a
    pop HL
    ld  (_penCol), HL
    ret
int_end:
;--------------- Interrupt routine ----------------


;C = horizontal number
GenHorzInfo:
    push    BC
    sla C
    sla C
    sla C
    ld  A, (Size)
    and A
    jr  z, GenHorzInfo_
    sla C
GenHorzInfo_:
    ld  HL, LevelMatrix
    ld  B, 0
    add HL, BC
    ld  DE, InfoTxtH
    push    DE
    ld  DE, 0
SearchBlackX_Loop:
    ld  A, (Size)
    and A
    ld  B, 8
    jr  z, SearchBlackX
    ld  B, 16
SearchBlackX:
    ld  A, (HL)
    and A
    jr  nz, SearchBlackX_1
SearchBlackX_0:
    cp  E           ;last tile?
    jr  z, SearchBlackX_
DispNum_X:
    ld  A, D
    pop DE
    cp  10
    jr  c, DispNum_X_
    add A, 'A'-'0'-10
DispNum_X_:
    add A, '0'
    ld  (DE), A
    inc DE
    ld  A, ' '
    ld  (DE), A
    inc DE
    push    DE
    ld  D, 0
    jr  SearchBlackX_
SearchBlackX_1:
    inc D
    .db $DD \ ld H, B
    .db $DD \ dec H
    jr  z, DispNum_X
    cp  E
    jr  z, SearchBlackX_
    ld  D, 1
SearchBlackX_:
    ld  E, (HL)
    inc HL
    djnz    SearchBlackX
    pop DE
    sub A
    ld  (DE), A
    pop BC
    call    DispHorzInfo
    ret

;C = horizontal number
DispHorzInfo:
    push    BC
    sla C
    ld  A, (Size)
    and A
    jr  nz, DispHorzInfo_1
    sla C
DispHorzInfo_1:
    ld  A, C
    add A, 32
    cp  58
    jr  c, DispHorzInfo_
    ld  A, 58
DispHorzInfo_:
    ld  (_penRow), A
    ld  A, 1
    ld  (_penCol), A
    ld  HL, InfoTxtH
    call    _vputs
    pop BC
    ret

;B = vertical number
GenVertInfo:
    push    BC
    ld  HL, LevelMatrix
    ld  C, B
    ld  B, 0
    add HL, BC
    ld  DE, InfoTxtV
    push    DE
    ld  DE, 0
SearchBlackY_Loop:
    ld  A, (Size)
    and A
    ld  B, 8
    jr  z, SearchBlackY
    ld  B, 16
SearchBlackY:
    ld  A, (HL)
    and A
    jr  nz, SearchBlackY_1
SearchBlackY_0:
    cp  E           ;last tile?
    jr  z, SearchBlackY_
DispNum_Y:
    ld  A, D
    pop DE
    cp  10
    jr  c, DispNum_Y_
    add A, 'A'-'0'-10
DispNum_Y_:
    add A, '0'
    ld  (DE), A
    inc DE
    push    DE
    ld  D, 0
    jr  SearchBlackY_
SearchBlackY_1:
    inc D
    .db $DD \ ld H, B
    .db $DD \ dec H
    jr  z, DispNum_Y
    cp  E
    jr  z, SearchBlackY_
    ld  D, 1
SearchBlackY_:
    ld  E, (HL)
    push    DE
    ld  A, (Size)
    and A
    ld  DE, 8
    jr  z, SearchBlackY_Add
    add HL, DE
SearchBlackY_Add:
    add HL, DE
    pop DE
    djnz    SearchBlackY
    pop DE
    sub A
    ld  (DE), A
    pop BC
    call    DispVertInfo
    ret

DispVertInfo:
    push    BC
    sla B
    ld  A, (Size)
    and A
    jr  nz, DispVertInfo_1
    sla B
DispVertInfo_1:
    ld  A, B
    add A, 67
    cp  92
    jr  c, DispVertInfo_
    ld  A, 94
DispVertInfo_:
    ld  (_penCol), A
    ld  B, A
    sub A
    ld  (_penRow), A
    ld  HL, InfoTxtV
DispVertLoop:
    ld  A, (HL)
    inc HL
    and A
    jr  z, DispVertDone
    call    _vputmap
    ld  A, (_penRow)
    add A, 6
    ld  (_penRow), A
    cp  31
    jr  c, DispVertLoop_
    sub A
    ld  (_penRow), A
    ld  A, B
    add A, 5
    ld  B, A
DispVertLoop_:
    ld  A, B
    ld  (_penCol), A
    jr  DispVertLoop
DispVertDone:
    pop BC
    ret


DispA:                                  ;Routine to Display A [By: Matthew Shepcar]
 ld l,a                                 ;Loads a into l
 ld h,0                                 ;0 into H
DispHL:                                 ;Displays HL [By: Matthew Shepcar]
 xor a                                  ;Loads 0 into A
 ld de,-1                               ;Loads -1 into DE
 ld (_curRow),de                        ;Loads de into CurRow
 call 4A33h                             ;Calls 4A33h
 dec hl                                 ;Decrease it
 res textInverse,(iy+textflags)
 jp _vputs                              ;Put on screen and return

InstallInt:
    res 2,(iy+$23)                   ;turn user int off so it won't get called by
                                     ;accident before we're ready
    ld hl,int_copy                   ;copy prog to user int buffer
    ld de,_alt_int_chksum+1            ;1 byte ahead of checksum
    ld bc,int_end-int_start          ;length of interrupt handler
    ldir                             ;hl is the source, de is the destination,
                                     ;and bc is the length
    ld a,(_alt_int_chksum+1)           ;set up checksum byte
    ld hl,_alt_int_chksum+($28*1)          ;load byte
    add a,(hl)                           ;add to total
    ld hl,_alt_int_chksum+($28*2)          ;load byte
    add a,(hl)                           ;add to total
    ld hl,_alt_int_chksum+($28*3)          ;load byte
    add a,(hl)                           ;add to total
    ld hl,_alt_int_chksum+($28*4)          ;load byte
    add a,(hl)                           ;add to total
    ld hl,_alt_int_chksum+($28*5)          ;load byte
    add a,(hl)                           ;add to total
    ld (_alt_int_chksum),a                 ;load checksum in its location
    set 2,(iy+$23)                       ;turn it on
    ret

OTH_PAUSE:
    call _getky
    cp K_ENTER
    jr nz,OTH_PAUSE
    ret

OTH_CLEAR:
        ld      (hl),0
OTH_FILL:
        ld      d,h
        ld      e,l
        inc     de
        ldir
        ret

ClearHorzInfo:
;    push    BC
;    sla C
;    ld  A, (Size)
;    and A
;    jr  nz, ClearHorzInfo_1
;    sla C
;ClearHorzInfo_1:
;    ld  A, C
;    add A, 32
;    cp  58
;    jr  c, ClearHorzInfo_
;    ld  A, 58
;ClearHorzInfo_:
;    ld  (_penRow), A
;    ld  A, 1
;    ld  (_penCol), A
;    ld  HL, Empty
;    call    _vputs
;    pop BC
;    ret
    push bc
    xor a
    ld de,8
    ld hl,$FC00+(16*32)
    ld c,32
CHILoop1:
    ld b,8
CHILoop2:
    ld (hl),a
    inc hl
    djnz CHILoop2
    add hl,de
    dec c
    jr nz,CHILoop1
    pop bc
    ret

ClearVertInfo:
;    push    BC
;    ld c,5
;    sla B
;    ld  A, (Size)
;    and A
;    jr  nz, ClearVertInfo_1
;    sla B
;ClearVertInfo_1:
;    ld  A, B
;    add A, 67
;    cp  92
;    jr  c, ClearVertInfo_
;    ld  A, 94
;ClearVertInfo_:
;    ld  (_penCol), A
;    ld  B, A
;    sub A
;    ld  (_penRow), A
;ClearVertLoop:
;    ld  HL, Empty2
;    dec c
;    jr  z, ClearVertDone
;    call    _vputs
;    ld  A, (_penRow)
;    add A, 6
;    ld  (_penRow), A
;    ld  A, B
;    ld  (_penCol), A
;    jr  ClearVertLoop
;ClearVertDone:
;    pop BC
;    ret
    push bc
    ld hl,$FC00+8
    ld de,12
    ld c,31
CVILoop:
    ld a,%01000000
    ld (hl),a
    inc hl
    ld b,3
CVILoop1:
    xor a
    ld (hl),a
    inc hl
    djnz CVILoop1
    ld a,%11000000
    cpl
    and (hl)
    ld (hl),a
    add hl,de
    dec c
    jr nz,CVILoop
    pop bc
    ret






;------------------------------------------------------
;   FIND_PIXEL by CLEM
;
;   121 cycles  27 bytes    Destroyes : none
;------------------------------------------------------

Find_Pixel:
    ld h,63
    ld a,c
    add a,a
    add a,a
    ld l,a
    ld a,b
    rra
    add hl,hl
    rra
    add hl,hl
    rra
    or l
    ld l,a
    ld a,b
    and 7
    cpl
    rlca
    rlca
    rlca
    ld (FP_Bit+1),a
    xor a
FP_Bit:
    set 0,a
    ret


TitlePic:
 .db $1F,$83,$80,$00,$00,$00,$00,$00,$3F,$E3,$80,$00,$00,$00,$00,$00
 .db $3F,$E0,$00,$00,$00,$00,$00,$00,$38,$F3,$07,$CE,$63,$E0,$FC,$3F
 .db $38,$E7,$1F,$CF,$EF,$F1,$FC,$FF,$71,$E7,$3C,$4F,$CE,$73,$84,$C1
 .db $7F,$C7,$38,$0E,$1C,$3B,$C0,$F0,$7F,$86,$70,$0C,$1C,$31,$F8,$FC
 .db $70,$0E,$70,$1C,$1C,$70,$7C,$3E,$70,$0E,$78,$1C,$1C,$74,$1D,$06
 .db $E0,$0E,$3F,$9C,$1F,$E7,$F9,$FE,$E0,$0E,$1F,$98,$0F,$C7,$F1,$FC

DoneStr:
     ;012345678901234567890
 .db "You completed all the"
 .db "levels in this beta. "
 .db "Thanks for playing!",0
GameOverStr:
 .db "--==* GAME OVER *==--",0
StageDone:
 .db "Press ENTER!",0
TimeUpStr:
 .db "Time",39,"s up!",0
MissStr:
 .db "Miss!",0
LevelSelectStr:
 .db "Select level:",0

ByStr:
 .db "by Andreas Ess",0
 .db "of",0
 .db "Icarus Productions",0
TimeStr:
 .db "Time:",0
ScrStr:
 .db "Score:",0
BestStr:
 .db "Best:",0
LevelStr:
 .db "Level:",0
LiveStr:
 .db "Live:",0
Stats:
 .db "Stats",0

BestScore:
 .dw 0
BestLevel:
 .db 0

Empty:
 .db "                       ",0
Empty2:
 .db "   ",0

RomPage:
 .db 0

#include "piclevel.h"

Pointer:
 .db 4,4
 .db %11100000
 .db %11000000
 .db %10100000
 .db %00010000

Tile44:
 .db 4,4
 .db %11110000
 .db %11110000
 .db %11110000
 .db %11110000

Tile22:
 .db 2,2
 .db %11000000
 .db %11000000

.end
